Package: quartify
Type: Package
Title: Convert R Scripts to 'Quarto' Markdown Documents
Version: 1.1.1
Authors@R: c(
    person("Damien", "Dotta", , "damien.dotta@live.fr", role = c("aut", "cre", "cph"))
    )
Description: Converts R scripts (.R) into 'Quarto' markdown documents (.qmd) with
    automatic formatting. Recognizes 'RStudio' code sections, preserves comments as
    narrative text, extracts metadata from special comments, and provides both
    programmatic functions and an interactive 'RStudio' add-in for easy conversion.
Language: en-US
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.2
URL: https://ddotta.github.io/quartify/,
        https://github.com/ddotta/quartify
BugReports: https://github.com/ddotta/quartify/issues
Imports: rstudioapi, cli, shiny, miniUI, later, base64enc, shinyFiles,
        quarto, utils, styler, lintr
Suggests: testthat (>= 3.0.0), dplyr, shinyalert
Config/testthat/edition: 3
Config/Needs/website: pkgdown
NeedsCompilation: no
Packaged: 2026-01-15 08:51:44 UTC; damien.dotta
Author: Damien Dotta [aut, cre, cph]
Maintainer: Damien Dotta <damien.dotta@live.fr>
Repository: CRAN
Date/Publication: 2026-01-21 18:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 14:39:49 UTC; unix
